"""Fixtures for sqgen_risk tests."""

import pytest


@pytest.fixture
def test_model_data() -> dict:
    """Return test model data."""
    return {"id": 1, "model_id": "model-1", "user_id": "user-1", "name": "Test Model"}


@pytest.fixture
def test_inference_data() -> dict:
    """Return test inference data."""
    return {
        "id": 1,
        "user_id": "user-1",
        "inference_request_id": "request-1",
        "model_id": "model-1",
        "created_at": "2025-06-29T12:00:00",
    }
